﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml;
using System.IO;
using System.Data;
using System.Data.SqlClient;


namespace NAVConnector
{


    public class NAVData
    {
        public Provider _provider;
        private string _user;

        public NAVData(string user)
        {
            _provider = new Provider();
            _user = user;
        }

        public NAVData(string user, string host, int port)
        {
            _user = user;
            _provider = new Provider(host,port);
        }

        public NAVData(string user, Provider provider)
        {
            _user = user;
            _provider = provider;
        }

        public string ContextUrl()
        {
            try
            {

                String resultXml = String.Empty;

                Dictionary<string, string> args = new Dictionary<string, string>();
                args.Add("type", "contexturl");

                _provider.SendCommand(args, out resultXml);

                XmlDocument xmldoc = new XmlDocument();
                xmldoc.LoadXml(resultXml);

                return xmldoc.SelectSingleNode("result").InnerText;
            }
            catch
            {
                return String.Empty;
            }
        }

        public string CompanyName()
        {
            try
            {
                String resultXml = String.Empty;

                Dictionary<string, string> args = new Dictionary<string, string>();
                args.Add("type", "companyname");

                _provider.SendCommand(args, out resultXml);

                XmlDocument xmldoc = new XmlDocument();
                xmldoc.LoadXml(resultXml);

                return xmldoc.SelectSingleNode("result").InnerText;
            }
            catch
            {
                return String.Empty;
            }
        }

        public string UserID()
        {
            try
            {
                String resultXml = String.Empty;

                Dictionary<string, string> args = new Dictionary<string, string>();
                args.Add("type", "userid");
                args.Add("user", _user);

                _provider.SendCommand(args, out resultXml);

                XmlDocument xmldoc = new XmlDocument();
                xmldoc.LoadXml(resultXml);

                return xmldoc.SelectSingleNode("result").InnerText;
            }
            catch
            {
                return String.Empty;
            }
        }


        public DataSet GetTable(int id,string filter)
        {
            try
            {
                DataSet ds = new DataSet();
                String resultXml = String.Empty;

                Dictionary<string, string> args = new Dictionary<string, string>();
                args.Add("user", _user);
                args.Add("type", "select");
                args.Add("tableid", id.ToString());
                args.Add("filter", filter);

                _provider.SendCommand(args, out resultXml);

                TextReader r = new StringReader(resultXml);
                ds.ReadXml(r);                
                
                return ds;
            }
            catch
            {
                return null;
            }
        }


        public bool DeleteRecord(int id, string recordid)
        {
            try
            {
                String resultXml = String.Empty;

                Dictionary<string, string> args = new Dictionary<string, string>();
                args.Add("user", _user);
                args.Add("type", "select");
                args.Add("tableid", id.ToString());
                args.Add("recordid", recordid.ToString());

                _provider.SendCommand(args, out resultXml);

                return true;
            }
            catch
            {
                return false;
            }
        }

        public DataSet hr_employee(int year)
        {
            try
            {
                DataSet ds = new DataSet();
                String resultXml = String.Empty;

                Dictionary<string, string> args = new Dictionary<string, string>();
                args.Add("type", "hr_employee");
                args.Add("user", _user);
                args.Add("year", year.ToString());

                _provider.SendCommand(args, out resultXml);

                TextReader r = new StringReader(resultXml);
                ds.ReadXml(r);

                return ds;
            }
            catch
            {
                return null;
            }
        }


        public DataSet hr_get_absence(int year)
        {
            try
            {
                DataSet ds = new DataSet();
                String resultXml = String.Empty;

                Dictionary<string, string> args = new Dictionary<string, string>();
                args.Add("user", _user);
                args.Add("type", "hr_get_absence");
                args.Add("year", year.ToString());

                _provider.SendCommand(args, out resultXml);

                TextReader r = new StringReader(resultXml);
                ds.ReadXml(r);

                return ds;
            }
            catch
            {
                return null;
            }
        }


        public bool hr_post_absence(DateTime dt, string cause)
        {
            try
            {
                DataSet ds = new DataSet();
                String resultXml = String.Empty;

                Dictionary<string, string> args = new Dictionary<string, string>();
                args.Add("user", _user);
                args.Add("type", "hr_post_absence");
                args.Add("year", dt.Year.ToString());
                args.Add("month", dt.Month.ToString());
                args.Add("day", dt.Day.ToString());
                args.Add("cause", cause);

                _provider.SendCommand(args, out resultXml);

                TextReader r = new StringReader(resultXml);
                ds.ReadXml(r);

                return true;
            }
            catch
            {
                return false;
            }
        }


        public bool hr_delete_absence(DateTime dt)
        {
            try
            {
                DataSet ds = new DataSet();
                String resultXml = String.Empty;

                Dictionary<string, string> args = new Dictionary<string, string>();
                args.Add("user", _user);
                args.Add("type", "hr_delete_absence");
                args.Add("year", dt.Year.ToString());
                args.Add("month", dt.Month.ToString());
                args.Add("day", dt.Day.ToString());                

                _provider.SendCommand(args, out resultXml);

                TextReader r = new StringReader(resultXml);
                ds.ReadXml(r);

                return true;
            }
            catch
            {
                return false;
            }
        }


        public static DateTime NAVConvertDT(string date)
        {
            DateTime dt = new DateTime
            (
                Convert.ToInt32(date.Split('-')[0].ToString()),
                Convert.ToInt32(date.Split('-')[1].ToString()),
                Convert.ToInt32(date.Split('-')[2].ToString())
            );
            return dt;
        }



    }
}
